<div align="center">

# YetAnotherPicSearch

[![license](https://img.shields.io/github/license/NekoAria/YetAnotherPicSearch)](https://raw.githubusercontent.com/NekoAria/YetAnotherPicSearch/master/LICENSE)
![python](https://img.shields.io/badge/python-3.8+-blue)
[![release](https://img.shields.io/github/v/release/NekoAria/YetAnotherPicSearch)](https://github.com/NekoAria/YetAnotherPicSearch/releases)

基于 [nonebot2](https://github.com/nonebot/nonebot2) 及 [PicImageSearch](https://github.com/kitUIN/PicImageSearch) 的另一个 Nonebot 搜图插件

</div>

## 项目简介

主要受到 [cq-picsearcher-bot](https://github.com/Tsuk1ko/cq-picsearcher-bot) 的启发。我只需要基础的搜图功能，于是忍不住自己也写了一个，用来搜图、搜番、搜本子。

目前支持的搜图服务：

- [saucenao](https://saucenao.com)
- [ascii2d](https://ascii2d.net)
- [iqdb](https://iqdb.org)
- [exhentai](https://exhentai.org)
- [whatanime](https://trace.moe)

目前适配的是 `OneBot V11` ，没适配 QQ 频道。

## 文档目录

- [使用教程](docs/使用教程.md)
- [部署教程](docs/部署教程.md)

## 效果预览

<p float="left">
    <img src="docs/images/image01.jpg" width="32%" />
    <img src="docs/images/image02.jpg" width="32%" />
    <img src="docs/images/image03.jpg" width="32%" />
</p>

## 感谢名单

- [cq-picsearcher-bot](https://github.com/Tsuk1ko/cq-picsearcher-bot)
- [PicImageSearch](https://github.com/kitUIN/PicImageSearch)
